#!/bin/ksh -x
#######################################################################
# script to replace IDS onunload/onload commands
# TODO Needs some error handling
#######################################################################
#----------------------------------------------------------------------
# globals
#----------------------------------------------------------------------
CREATE_DDL=create_ddl.sql
ADD_CONSTRAINTS=add_constraints.sql
INPUT_SQL=dbschema.sql

#----------------------------------------------------------------------
# functions
#----------------------------------------------------------------------

# print usage
function usage {
	echo "Usage:"
	echo "   $0 <database> <zipfile> <Informix dir>"
}


# strip out all of the ALTER commands which in this instance are adding FK constraints
# write all lines *not* maching pattern to create_ddl.sql script (should be able to do this in one line!)
function create_scripts {
  sed -e '/^alter/,/\;/!d' $INPUT_SQL > $ADD_CONSTRAINTS
  sed -e '/^alter/,/\;/d' $INPUT_SQL  > $CREATE_DDL
}

# drops and creates the database using the create_ddl.sql script
function create_database {
  # drop the current database if it exists
  echo drop database $DBNAME | dbaccess -e sysmaster

  # create the empty datbase
  echo create database $DBNAME | dbaccess -e sysmaster

  # run the DDL script to create the database tables
  dbaccess -e $DBNAME $CREATE_DDL
}

# loads the data from the input ZIP file
function load_data {
  # for each table, load the data
  for TAB in $(ls -d */)
  do
    cd $TAB
    echo load from $(basename $TAB).unload insert into $(basename $TAB) | dbaccess -e $DBNAME 
    cd ..
  done
}

# runs script to alter tables enabling FK relationships
function enable_fks {
  # now, run the script to create FK constraints
  dbaccess -e $DBNAME add_constraints.sql
}

# turns on logging for the newly created database
function enable_logging {
  # turn on logging ANSI mode
  # ontape -s -U $DBNAM
 > $BACKUPFILE
 ontape -s -U $DBNAME -L 0 > $BACKUPFILE -t STDIO 
}
#----------------------------------------------------------------------
# main
#----------------------------------------------------------------------

if [[ $# -ne 3 ]];
then 
	usage
	exit 1
fi

DBNAME=$1
ZIPFILE=$2
INFORMIXDIR=$3
TMPWORK=/tmp/$$$DBNAME
BACKUPFILE=$TMPWORK/bkp.bkp
. $INFORMIXDIR/optimrepo.ksh
. $INFORMIXDIR/setenvutf8.ksh
# create temp working directory
mkdir -p $TMPWORK
unzip $ZIPFILE -d $TMPWORK

cd $TMPWORK/*
create_scripts 
create_database
load_data
enable_fks
enable_logging

rm -rf $TMPWORK

exit 0
