#!/bin/ksh -x

#----------------------------------------------------------------------
# functions
#----------------------------------------------------------------------
# print usage
function usage {
	echo "Usage:"
	echo "   $0 <database> <load file name> <Informix Dir>"
}

# unloads the specified file to a directory
function unload_table {
	echo "TABLE ==> $1"
	mkdir -p ${TEMP_DBUNLOAD_DIR}/${1}
	echo "UNLOAD TO $TEMP_DBUNLOAD_DIR/${1}/${1}.unload SELECT * from informix.${1}" |\
	     dbaccess -e ${DBNAME}
}

# creates the <database>.sql script to be run once datbase is dropped prior to loading
function create_dbschema_script {
	dbschema -q -d $DBNAME -t all -f all -r all -p all > ${TEMP_DBUNLOAD_DIR}/dbschema.sql
}

#----------------------------------------------------------------------
# main
#----------------------------------------------------------------------

if [[ $# -ne 3 ]];
then 
	usage
	exit 1
fi

DBNAME=$1
LOADFILENAME=$2
INFORMIXDIR=$3
TEMP_DBUNLOAD_DIR=/tmp/$DBNAME
. $INFORMIXDIR/optimrepo.ksh
. $INFORMIXDIR/setenvutf8.ksh
mkdir -p $TEMP_DBUNLOAD_DIR

original_dir=$(pwd)
create_dbschema_script

# get the list of tables for the given database
# the word is that tabids 100+ are user tables, so let's grab 'em
table_list=$(echo "select tabname from informix.systables where tabid > 99 and tabtype = 'T'" |\
  dbaccess -e ${DBNAME}|\
  grep '^tabname' |\
  awk '{print $2}')
  
# go through list of tables
for TABLE in $table_list
do
  unload_table $TABLE
done

# zip the file and remove temp work directory
cd /tmp
zip -r ${DBNAME}.load.zip $DBNAME
# check return code from zip
cp ${DBNAME}.load.zip ${LOADFILENAME}
rm ${DBNAME}.load.zip
rm -rf $TEMP_DBUNLOAD_DIR
cd $original_dir
exit 0
